package com.coob.aframe.base;

import com.coob.aframe.util.DateUtil;
import com.coob.aframe.util.FileUtil;
import com.coob.aframe.util.UUIDUtil;
import org.apache.commons.io.FileUtils;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.*;

@Controller
@RequestMapping("/file")
public class FileController extends BaseController {

    /**
     * 上传附件, 对应页面上传单个文件处理
     * @param file
     */
    @ResponseBody
    @RequestMapping(value = "/upload", method={RequestMethod.POST, RequestMethod.GET}, produces = "application/json;charset=utf-8") // 防止json传输出现乱码
    public R upload(@RequestParam("file") MultipartFile file) {
        //创建路径
        String urlMk = DateUtil.getCurDateStr("yyyy/MM/dd/");
        String bPath = Application.Upload_File_Path;
        FileUtil.mkDir(bPath + urlMk);

        //本地缓存文件路径
        String _fName = file.getOriginalFilename();
        String _Format = _fName.substring(_fName.lastIndexOf("."));
        String uuid = UUIDUtil.getUUID();
        String fileName = uuid + _Format;
        String url = urlMk + fileName;

        try {
            //保存文件
            FileUtil.saveFile(file, bPath + url);
            //上传文件服务器
            return R.ok().put("furl", url);

        } catch (IOException e) {
            e.printStackTrace();
        }

        return R.error();
    }


    /**
     * 通用下载
     * @param u 路径
     * @param m 文件名（get方式中文出现乱码，需要设置tomcat字符集)
     * @return
     * @throws IOException
     */
    @RequestMapping(value="/down", method={RequestMethod.GET, RequestMethod.POST}, produces = "application/json;charset=utf8")
    public void download(String u, String m, HttpServletResponse response) throws IOException {
        File file = new File(Application.Upload_File_Path+u);
        if( file != null && file.exists() && file.isFile() ){
            if( m == null && file != null ){
                m = file.getName();
            }

            response.setHeader("content-type", "application/octet-stream");
            response.setContentType("application/octet-stream");
            response.setHeader("Content-Disposition", "attachment;filename="+new String(m.getBytes("utf-8"), "ISO-8859-1"));

            byte[] buffer = new byte[1024];
            FileInputStream fis = null;
            BufferedInputStream bis = null;

            try {
                fis = new FileInputStream(file);
                bis = new BufferedInputStream(fis);
                OutputStream os = response.getOutputStream();
                int i = bis.read(buffer);
                while (i != -1) {
                    os.write(buffer, 0, i);
                    i = bis.read(buffer);
                }
            } catch (Exception e) {
                e.printStackTrace();
            } finally {
                if (bis != null) {
                    try {
                        bis.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
                if (fis != null) {
                    try {
                        fis.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
        }
    }


    /**
     * 图片查看
     * @param u 路径
     * @return
     * @throws IOException
     */
    @RequestMapping(value="/img", method={RequestMethod.GET, RequestMethod.POST}, produces = "application/json;charset=utf8")
    public ResponseEntity<byte[]> showImg(String u) throws IOException {
        String base = Application.Upload_File_Path;
        String nm = null;
        File file= new File(base + u);

        System.out.println(file);

        if( file != null && file.exists() && file.isFile() ){
            if( nm == null && file != null ){
                nm = file.getName();
            }
            HttpHeaders headers = new HttpHeaders();
            String _fileName = new String(nm.getBytes("UTF-8"),"iso-8859-1");		//为了解决中文名称乱码问题
            headers.setContentDispositionFormData("attachment", _fileName);
            //headers.set(HttpHeaders.CONTENT_DISPOSITION, "attachment; filename=\"" + _fileName + "\"");
            headers.setContentType(MediaType.APPLICATION_OCTET_STREAM);
            return new ResponseEntity<byte[]>(FileUtils.readFileToByteArray(file), headers, HttpStatus.OK);
        } else {
            return null;
        }
    }
}
