package com.coob.aframe.util;

import net.coobird.thumbnailator.Thumbnails;
import net.coobird.thumbnailator.Thumbnails.Builder;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.fileupload.util.Streams;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.multipart.MultipartFile;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.*;

/**
 * 文件处理工具类
 */
public class FileUtil {


    /**
     * 创建目录
     * @param path
     */
    public static void mkDir(String path) {
        String[] strs = path.split("/");

        String p = "";
        for (String s : strs) {
            p = p + s + "/";
            File file = new File(p);
            if (!file.isDirectory()) {
                file.mkdir();
            }
        }
    }


    /**
     * 图片压缩处理
     *
     * @param multipartFile
     * @param filePath
     * @return
     * @throws IOException
     */
    public static void saveFile(MultipartFile multipartFile, String filePath) throws IOException {
        saveStreamToFile(multipartFile.getInputStream(), filePath);
    }


    /**
     * 保存文件
     * @param inputStream
     * @param filePath
     * @throws FileNotFoundException
     * @throws IOException
     */
    public static void saveStreamToFile(InputStream inputStream, String filePath) throws FileNotFoundException, IOException {
        File file = new File(filePath);
        BufferedInputStream instream = new BufferedInputStream(inputStream);
        BufferedOutputStream outstream = new BufferedOutputStream(new FileOutputStream(file));
        Streams.copy(instream, outstream, true);
        if (instream != null) {
            instream.close();
        }
        if (outstream != null) {
            outstream.close();
        }
    }


    /**
     * 输入流转文件
     * @param ins
     * @param file
     */
    public static void inputStreamToFile(InputStream ins, File file) {
        BufferedOutputStream bos = null;
        BufferedInputStream bis = new BufferedInputStream(ins);
        try {
            bos = new BufferedOutputStream(new FileOutputStream(file));
            int bytesRead = 0;
            byte[] buffer = new byte[8192];
            while ((bytesRead = bis.read(buffer, 0, 8192)) != -1) {
                bos.write(buffer, 0, bytesRead);
            }
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (ins != null) {
                try {
                    ins.close();
                } catch (IOException e) {
                }
                ins = null;
            }
            if (bos != null) {
                try {
                    bos.close();
                } catch (IOException e) {
                }
                bos = null;
            }
            if (bis != null) {
                try {
                    bis.close();
                } catch (IOException e) {
                }
                bis = null;
            }
        }
    }


    /**
     * 文件流转Base64
     *
     * @param in
     * @return
     */
    public static String getBase64FromInputStream(InputStream in) {
        // 将文件转化为字节数组字符串，并对其进行Base64编码处理
        byte[] data = null;
        // 读取字节数组
        try {
            ByteArrayOutputStream swapStream = new ByteArrayOutputStream();
            byte[] buff = new byte[100];
            int rc = 0;
            while ((rc = in.read(buff, 0, 100)) > 0) {
                swapStream.write(buff, 0, rc);
            }
            data = swapStream.toByteArray();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
        }

        return new String(Base64.encodeBase64(data));
    }

    public static void delete(String url) {
        try {
            File file = new File(url);
            if (file.exists()) {
                file.delete();
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 是否是图片
     *
     * @param inputStream
     * @return
     */
    public static boolean isImage(InputStream inputStream) {
        if (inputStream == null) {
            return false;
        }
        try {
            BufferedImage image = ImageIO.read(inputStream);
            return null != image;
        } catch (IOException e) {
        }
        return false;
    }

    /**
     * 是否是视频 目前仅仅支持MP4
     *
     * @param
     * @return
     */
    public static boolean isVideo(String fileType) {
        if (StringUtils.isBlank(fileType)) {
            return false;
        }
        return "mp4".equals(fileType.toLowerCase());
    }

    public static boolean isPdf(String fileType) {
        if (StringUtils.isBlank(fileType)) {
            return false;
        }
        return "pdf".equals(fileType.toLowerCase());
    }

    /**
     * 图片压缩处理
     * @param multipartFile
     * @param filePath
     * @return
     * @throws IOException
     */
    public static boolean imgThumbnail(MultipartFile multipartFile, String filePath) throws IOException {
        boolean isThumbnail = true;		//是否压缩

        //压缩文件，判断是否压缩
        long fileSize = multipartFile.getSize() / 1024; //字节转为k
        double scale = 0.0, quality = 0.0;
        if( fileSize < 250 ){
            //小于250k，不压缩
            isThumbnail = false;
        } else if( fileSize < 500 ){
            scale = 1.0;
            quality = 0.75;
        } else if( fileSize < 1000 ){
            scale = 1.0;
            quality = 0.5;
        } else {
            scale = 0.5;
            quality = 0.25;
        }

        if( isThumbnail ){
            //图片压缩
            Thumbnails.of(new InputStream[] {multipartFile.getInputStream()})
                    .scale(scale)
                    .outputQuality(quality)
                    .toFile(filePath);
        }

        return isThumbnail;
    }


    /**
     * 生成图片缩略图
     *
     * @param inputStream 文件
     * @param filePath 缩略图存放路径和文件名
     * @param width
     * @param height
     * @throws IOException
     */
    public static void imgThumbnail(InputStream inputStream, String filePath, int width, int height)
            throws IOException {
        Builder<? extends InputStream> thumbnail = Thumbnails.of(inputStream);
        thumbnail.size(width, height);
        thumbnail.toFile(filePath);
    }
}
