package com.coob.modules.api;

import com.coob.aframe.base.R;
import com.coob.modules.api.vo.BmVo;
import com.coob.modules.api.vo.BmjxVo;
import com.coob.modules.api.vo.RylbVo;
import com.coob.modules.tg.domain.Tgry;
import com.coob.modules.tg.domain.Tgxm;
import com.coob.modules.tg.domain.Tgxx;
import com.coob.modules.tg.domain.Xmxx;
import com.coob.modules.tg.service.TgryService;
import com.coob.modules.tg.service.TgxmService;
import com.coob.modules.tg.service.TgxxService;
import com.coob.modules.tg.service.TgyhService;
import com.coob.modules.tg.service.XmxxService;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.List;

/**
 * 微信端，团购报名Api
 *  报名、查询
 */
@Controller
@RequestMapping("/api/tg")
public class TgbmApi extends BaseApi {
    @Resource
    private TgxxService tgxxService;
    @Resource
    private TgxmService tgxmService;
    @Resource
    private TgryService tgryService;
    @Resource
    private TgyhService tgyhService;
    @Resource
    private XmxxService xmxxService;


    /**
     * 查询报名人员列表
     * @param key
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/rylb", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R rylb(String key, Integer hdid, Integer xmid){
        boolean flag = this.checkKey(key);
        if( !flag ) {
            return R.error(505, "数据请求异常");
        }

        if( hdid == null || hdid == 0 || xmid == null || xmid == 0 ) {
            return R.error(503, "业务请求异常");
        }

        Tgxx tgxx = this.tgxxService.selectById(hdid);
        RylbVo vo = new RylbVo(tgxx, xmid);

        return R.ok(200, "ok").put("data", vo);
    }


    /**
     * 团购报名
     * @param key
     * @param hdid
     * @param xmid
     * @param xm
     * @param sjhm
     * @param rylb
     * @param zjhm
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/bm", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R bm(String key, Integer hdid, Integer xmid, String xm, String sjhm, String rylb, String zjhm){
        boolean flag = this.checkKey(key);
        if( !flag ) {
            return R.error(505, "数据请求异常");
        }

        if( hdid == null || hdid == 0 || xmid == null || xmid == 0
            || xm == null || xm.length() == 0 || sjhm == null || sjhm.length() == 0 ) {
            return R.error(503, "业务请求异常");
        }

        Tgxx tgxx = this.tgxxService.selectById(hdid);
        if( tgxx == null ) {
            return R.error(500, "数据异常");
        }
        if( tgxx.getZt()  != 2 ) {
            return R.error(501, "该活动已关闭");
        }

        Tgxm tgxm = this.tgxmService.selectByTgidAndXmid(hdid, xmid);
        if( tgxm == null ) {
            return R.error(500, "数据异常");
        }

        //验证手机号是否已经报名
        Tgry tgry = this.tgryService.selectForCheck(hdid, xmid, sjhm);
        if( tgry != null ) {
            return R.error(501, "您已报名该团购楼盘, 不能重复报名");
        }

        //报名处理
        tgry = new Tgry(tgxm, xm, sjhm, rylb, zjhm);

        this.tgryService.saveBm(tgry);
        // 获取统计信息
        tgxm = this.tgxmService.selectById(tgxm.getId());
        Xmxx xmxx = this.xmxxService.selectById(tgxm.getXmid());
        BmVo bmVo = new BmVo(tgry.getXm(),tgxm.getBmrs(),xmxx.getKfdh());
        return R.ok(200, "报名成功").put("vo",bmVo);
    }


    /**
     * 根据手机号码，查询报名记录
     * @param key
     * @param hdid
     * @param sjhm
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/cx", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R cx(String key, Integer hdid, String sjhm) {
        boolean flag = this.checkKey(key);
        if( !flag ) {
            return R.error(505, "数据请求异常");
        }

        if( hdid == null || hdid == 0 || sjhm == null || sjhm.length() == 0 ) {
            return R.error(503, "业务请求异常");
        }

        //查询列表
        List<BmjxVo> list = this.tgryService.selectListBySjhmForWx(hdid, sjhm);

        for(BmjxVo vo : list) {
            vo.putYh();
        }

        int size = list.size();

        R r = null;
        if( size == 0 ) {
            r = R.ok(300, "没有查询到您的报名记录");
        } else {
            r = R.ok(200, "ok");
        }

        r.put("size", size).put("list", list);

        return r;
    }
}
