package com.coob.modules.api;

import com.coob.aframe.base.R;
import com.coob.modules.api.vo.GdTgxmVo;
import com.coob.modules.api.vo.TgxxVo;
import com.coob.modules.api.vo.XmListVo;
import com.coob.modules.api.vo.XmxxVo;
import com.coob.modules.tg.domain.Tgxm;
import com.coob.modules.tg.domain.Tgxx;
import com.coob.modules.tg.domain.Xmhx;
import com.coob.modules.tg.domain.Xmtp;
import com.coob.modules.tg.domain.Xmxx;
import com.coob.modules.tg.domain.XmxxZj;
import com.coob.modules.tg.service.TgxmService;
import com.coob.modules.tg.service.TgxxService;
import com.coob.modules.tg.service.TgyhService;
import com.coob.modules.tg.service.XmZjService;
import com.coob.modules.tg.service.XmhxService;
import com.coob.modules.tg.service.XmtpService;
import com.coob.modules.tg.service.XmxxService;
import com.coob.system.service.AreaService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * 微信端，团购信息Api
 *  查询团购活动、楼盘信息
 */
@Controller
@RequestMapping("/api/tg")
public class TgxxApi extends BaseApi {
    @Resource
    private AreaService areaService;
    @Resource
    private TgxxService tgxxService;
    @Resource
    private TgxmService tgxmService;
    @Resource
    private XmxxService xmxxService;
    @Resource
    private XmhxService xmhxService;
    @Resource
    private XmtpService xmtpService;
    @Resource
    private TgyhService tgyhService;
    @Resource
    private XmZjService xmZjService;


    /**
     * 查询正在进行的活动信息
     * @param key
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/list", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R list(String key){
        boolean flag = this.checkKey(key);
        if( !flag ) {
            return R.error(505, "数据请求异常");
        }

        //查询正在进行的活动 zt=2
        List<Tgxx> list = this.tgxxService.selectListForWx();
        List<TgxxVo> voList = new ArrayList<>();
        for( Tgxx tg : list ) {
            voList.add(new TgxxVo(tg));
        }

        return R.ok(200, "ok").put("size", voList.size()).put("list", voList);
    }


    /**
     * 查看活动下的楼盘列表
     * @param key
     * @param hdid
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/lps", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R lps(String key, Integer hdid, Integer pNum,Integer qx) {
        boolean flag = this.checkKey(key);
        if( !flag ) {
            return R.error(505, "数据请求异常");
        }

        if( hdid == null || hdid == 0 ) {
            return R.error(503, "业务请求异常");
        }

        Tgxx tgxx = this.tgxxService.selectById(hdid);
        if( tgxx == null ) {
            return R.error(500, "数据异常");
        }
        if( tgxx.getZt()  != 2 ) {
            return R.error(501, "该活动已关闭");
        }

        //更新互动浏览数
        this.tgxxService.updateLls(hdid);

        //查询该活动的项目列表
        Map<String,Object> params = new HashMap<>();
        params.put("tgid",hdid);
        params.put("qx",qx);
        super.offsetPage(pNum);

        List<Xmxx> result = this.xmxxService.selectListByTgidForWx(params);
        PageInfo<Xmxx> pageInfo = new PageInfo<>(result);
        // 获取分页数据结果
        List<Xmxx> xmList = pageInfo.getList();
        //查询项目效果图列表
        List<Xmtp> tpList = this.xmtpService.selectListXgtByTgidForWx(hdid);

        //封装数据
        List<XmListVo> list = new ArrayList<>();
        for( Xmxx xm : xmList ) {
            XmListVo vo = new XmListVo(hdid, xm, tpList);
            list.add(vo);
        }

        return R.ok(200, "OK").put("size", pageInfo.getTotal()).put("list", list);
    }

    /**
     * 查看活动下的楼盘详情
     * @param key
     * @param hdid
     * @param xmid
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/lp", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R lp(String key, Integer hdid, Integer xmid) {
        boolean flag = this.checkKey(key);
        if( !flag ) {
            return R.error(505, "数据请求异常");
        }

        if( hdid == null || hdid == 0 || xmid == null || xmid == 0 ) {
            return R.error(503, "业务请求异常");
        }

        Tgxx tgxx = this.tgxxService.selectById(hdid);
        if( tgxx == null ) {
            return R.error(500, "数据异常");
        }
        if( tgxx.getZt()  != 2 ) {
            return R.error(501, "该活动已关闭");
        }

        //更新浏览数(含托管活动、托管项目)
        this.tgxmService.updateLlsByTgidAndXmid(hdid, xmid);

        //查询项目信息
        Xmxx xmxx = this.xmxxService.selectById(xmid);

        //团购项目信息
        Tgxm tgxm = this.tgxmService.selectByTgidAndXmid(hdid, xmid);
        xmxx.setBmrs(tgxm.getBmrs());

        //在售户型
        List<Xmhx> hxList = this.xmhxService.selectHxListByXmid(xmid);

        //查询效果图
        List<Xmtp> xgtList = this.xmtpService.selectListByXmid(xmid, 1);

        //查询户型图
        List<Xmtp> hxtList = this.xmtpService.selectListByXmid(xmid, 2);

        //Todo:查询公示图
        List<Xmtp> gstList = this.xmtpService.selectListByXmid(xmid, 3);

        // 预售证、备案号
        List<XmxxZj> zjList = this.xmZjService.selectByXmid(xmid, 0);
        //封装数据
        XmxxVo vo = new XmxxVo(hdid, xmxx);
        vo.setKsrq(tgxx.getKsrq());
        vo.setJzrq(tgxx.getJzrq());

        for( Xmhx hx : hxList ) {
            vo.putHx(hx);
        }

        for( Xmtp tp : xgtList ) {
            vo.putXgt(tp);
        }

        for( Xmtp tp : hxtList ) {
            vo.putHxt(tp);
        }

        for( Xmtp tp : gstList ) {
            vo.putGst(tp);
        }

        vo.putYh(tgxm);

        for( XmxxZj xmzj : zjList ) {
            vo.putYhzh(xmzj.getZsh());
        }

        return R.ok(200, "ok").put("data", vo);
    }


    /**
     * 成团消息，用于首页滚动展示
     * 获取未结束的团购2、审批通过2（注意未撤销的-2） 团购项目 报名人数前十的项目信息
     * @param key
     * @return
     */
    @ResponseBody
    @RequestMapping("/ctmsg")
    public R ctmsg(String key){
        boolean flag = this.checkKey(key);
        if( !flag ) {
            return R.error(505, "数据请求异常");
        }

        List<GdTgxmVo> list = this.tgxmService.selectLpsByBmrs();

        return R.ok(200, "ok").put("size", list.size()).put("list", list);
    }
}
