package com.coob.modules.tg.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.R;
import com.coob.aframe.util.DateUtil;
import com.coob.modules.tg.domain.Tgry;
import com.coob.modules.tg.domain.Tgxm;
import com.coob.modules.tg.domain.Tgxx;
import com.coob.modules.tg.domain.Xmxx;
import com.coob.modules.tg.service.TgryService;
import com.coob.modules.tg.service.TgxmService;
import com.coob.modules.tg.service.TgxxService;
import com.coob.modules.tg.service.XmxxService;
import com.coob.system.domain.Area;
import com.coob.system.service.AreaService;
import com.github.pagehelper.PageInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 企业端团购业务
 * 1、展示未关闭的所有的 团购信息
 */
@RequestMapping("/tgyw/qy")
@Controller
public class QyTgywController extends BaseController {
    @Resource
    private TgxxService tgxxService;
    @Resource
    private TgxmService tgxmService;
    @Resource
    private AreaService areaService;
    @Resource
    private TgryService tgryService;
    @Resource
    private XmxxService xmxxService;


    /**
     * 团购业务-未结束列表
     *
     * @param model
     * @return
     */
    @RequestMapping(value = "/doList")
    public String doList(String tgmc, Model model) {
        Map<String, Object> params = new HashMap<>();
        params.put("tgmc", tgmc);
        params.put("jzzt", 4);      //仅查询未结束的团购
        super.setParamToSession(params);

        super.offsetPage(1);
        List<Tgxx> list = this.tgxxService.selectByParams(params);
        PageInfo<Tgxx> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("tgmc", tgmc);

        return "pages/ywglQy/tgyw/list";
    }

    /**
     * 团购业务-未结束列表
     *
     * @param model
     * @return
     */
    @RequestMapping(value = "/doPage")
    public String doPage(Integer pageNum,Model model) {
        Map<String,Object> params = this.getSessionParam();

        super.offsetPage(pageNum);
        List<Tgxx> list = this.tgxxService.selectByParams(params);
        PageInfo<Tgxx> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("tgmc", params.get("tgmc"));

        return "pages/ywglQy/tgyw/list";
    }

    /**
     * 跳转可操作详情展示页面
     *
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toView")
    public String toView(Integer id, Model model) {
        //查询托管信息
        Tgxx tgxx = this.tgxxService.selectById(id);
        List<Area> areas = this.areaService.selectList();

        model.addAttribute("tgxx", tgxx);
        model.addAttribute("areaList", areas);

        return "pages/ywglQy/tgyw/view";
    }


    /**
     * 显示项目列表
     * @param tgid
     * @param model
     * @return
     */
    @RequestMapping(value = "/xmList")
    public String xmList(Integer tgid, Model model) {
        Integer qyid = this.getCurrentUser().getDepartId();

        // 1、查询团购信息绑定的团购项目
        List<Tgxm> tgxmList = this.tgxmService.selectListXmByTgidAndQyid(tgid, qyid);

        //查询报名人员
        List<Tgry> tgryList = this.tgryService.selectListByTgid(tgid);

        for (Tgxm tx : tgxmList) {
            if(tgryList != null){
                for (Tgry tgry : tgryList) {
                    //已推送本项目的 报名人员 推送状态 1 未推送 2 已推送
                    if(tgry.getTszt() == 2 && tx.getId().equals(tgry.getTgxmid())){
                        tx.putTgry(tgry);
                    }
                }
            }
        }

        model.addAttribute("tgxmList", tgxmList);

        return "pages/ywglQy/tgyw/xmList";
    }

    /**
     * 进入新增项目页面
     * @param tgid
     * @param model
     * @return
     */
    @RequestMapping(value = "/toXmxz")
    public String toXmxz(Integer tgid, Model model) {
        Tgxx tgxx = tgxxService.selectById(tgid);

        Integer qyid = this.getCurrentUser().getDepartId();

        // 查查询企业名下审核通过的项目信息
        List<Xmxx> xmxxList = xmxxService.selectListShtgByQyid(qyid);

        //查询已经添加（过）的项目
        List<Xmxx> xmList = this.xmxxService.selectListByTgid(tgid, null, null, null);

        //比对数据
        List<Xmxx> list = new ArrayList<>();
        for( Xmxx xm : xmxxList ) {
            int flag = 0;
            for( Xmxx x : xmList ) {
                if( xm.getId().intValue() == x.getId().intValue() ) {
                    flag = 1;
                    break;
                }
            }
            if( flag == 0 ) {
                list.add(xm);
            }
        }

        model.addAttribute("xmxxList", list);
        model.addAttribute("tgxx", tgxx);

        return "pages/ywglQy/tgyw/xmxz";
    }


    /**
     * 保存新增信息
     * @param tgxm
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/doXmxz", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doXmxz(Tgxm tgxm) {
//        String msg = tgxm.checkAdd();
//        if(StringUtils.isBlank(msg)){
//            return R.error(msg);
//        }
        Integer tgid = tgxm.getTgid();
        Integer xmid = tgxm.getXmid();
        Tgxm tx = tgxmService.selectByTgidAndXmid(tgid, xmid);
        if ( tx != null) {
            return R.error("不能重复添加楼盘");
        }
        Xmxx xmxx = xmxxService.selectById(xmid);
        String tjr = this.getCurrentUser().getUserName();

        //保存数据
        tgxm.initData(xmxx,tjr);
        this.tgxmService.insert(tgxm);

        return R.ok("信息保存成功");
    }

    /**
     * 保存新增信息
     * @param tgxm
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/updateXmxz", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R updateXmxz(Tgxm tgxm) {
        String msg = tgxm.checkAdd();
        if(StringUtils.isBlank(msg)){
            return R.error(msg);
        }
        int update = this.tgxmService.update(tgxm);
        if(update == 0){
            return R.error("更新失败");
        }
        // 再次查询
        return R.ok("更新成功");
    }

    /**
     * 查看人员列表
     * @param txid
     * @param model
     * @return
     */
    @RequestMapping("/ryList")
    public String ryList(Integer txid, Model model){
        List<Tgry> ryList = this.tgryService.selectListByTgxmid(txid, 2);
        model.addAttribute("ryList", ryList);

        return "pages/ywglQy/tgyw/ryList";
    }

    /**
     * 确认成交
     * @param id
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/doJc", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doJc(Integer id) {
        Tgry tgry = this.tgryService.selectById(id);
        if( tgry.getCjzt() == 2 ) {
            return R.ok();
        }

        tgry.setCjzt(2);
        tgry.setCjr(this.getCurrentUser().getUserName());
        tgry.setCjsj(DateUtil.getCurTime());

        this.tgryService.saveCj(tgry);

        return R.ok();
    }
}
