package com.coob.modules.tg.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.LoginUser;
import com.coob.aframe.base.R;
import com.coob.aframe.util.DateUtil;
import com.coob.modules.tg.domain.Qyxx;
import com.coob.modules.tg.domain.Tgxx;
import com.coob.modules.tg.service.QyxxService;
import com.coob.modules.tg.service.TgxxService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * (TQyxx)表控制层
 * @author makejava
 * @since 2024-08-01 17:01:36
 */
@Controller
@RequestMapping("/qyxx/gl")
public class QyxxController extends BaseController {
    @Resource
    private QyxxService qyxxService;
    @Resource
    private TgxxService tgxxService;

    /**
     * 查询企业信息列表
     *
     * @param qymc
     * @param pageNum
     * @param model
     * @return
     */
    @RequestMapping(value = "/doList")
    public String doList(String qymc, Integer pageNum, Model model) {
        Map<String, Object> params = new HashMap<>();
        params.put("qymc", qymc);
        params.put("state", 1);
        super.setParamToSession(params);

        super.offsetPage(pageNum);
        List<Qyxx> list = this.qyxxService.selectByParams(params);
        PageInfo<Qyxx> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("qymc", qymc);

        return "pages/ywgl/qyxx/list";
    }


    /**
     * 信息新增
     * @param model
     * @return
     */
    @RequestMapping(value = "/toAdd")
    public String toAdd(Model model) {
        Qyxx qyxx = new Qyxx();
        model.addAttribute("qyxx", qyxx);
        return "pages/ywgl/qyxx/add";
    }

    /**
     * 新增数据
     * @param qyxx 实体
     * @return 新增结果
     */
    @ResponseBody
    @RequestMapping(value = "/doAdd", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doAdd(Qyxx qyxx) {
        Qyxx qy = qyxxService.selectByQymc(qyxx.getQymc());
        if ( qy != null ) {
            return R.error("企业名称重复");
        }
        // 操作人赋值
        LoginUser currentUser = this.getCurrentUser();
        qyxx.setCzr(currentUser.getUserName());
        qyxx.setCzsj(DateUtil.getCurTime());
        qyxx.setState(1);

        this.qyxxService.insert(qyxx);

        return R.ok("信息保存成功").put("qy", qyxx);
    }


    /**
     * 信息新增
     *
     * @param model
     * @return
     */
    @RequestMapping(value = "/toEdit")
    public String toEdit(Integer id, Model model) {
        Qyxx qyxx = this.qyxxService.selectById(id);

        model.addAttribute("qyxx", qyxx);

        return "pages/ywgl/qyxx/edit";
    }

    /**
     * 编辑数据
     * @param qyxx 实体
     * @return 编辑结果
     */
    @ResponseBody
    @RequestMapping(value = "/doEdit", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doEdit(Qyxx qyxx) {
        Qyxx qy = qyxxService.selectByQymc(qyxx.getQymc());
        if (qy != null && !qy.getId().equals(qyxx.getId())) {
            return R.error("企业名称重复");
        }

        // 创造人赋值
        LoginUser currentUser = this.getCurrentUser();
        qyxx.setCzr(currentUser.getUserName());
        qyxx.setCzsj(DateUtil.getCurTime());

        this.qyxxService.update(qyxx);

        return R.ok("信息保存成功").put("qy", qyxx);
    }


    /**
     * 删除信息
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/doDel")
    public String doDel(Integer id, Model model) {
        //判断企业下的项目是否参团，如果参团，不允许删除
        List<Tgxx> tgxxs = tgxxService.selectByQyid(id);
        if(tgxxs != null && tgxxs.size() > 0){
            alert("有参团的项目不允许删除");
        }else {
            this.qyxxService.deleteById(id);
            alert("信息删除成功");
        }
        return "redirect:doList";
    }


    /**
     * 企业详情
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toView")
    public String toView(Integer id, Model model) {

        return "pages/ywgl/qyxx/view";
    }
}

