package com.coob.modules.tg.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.LoginUser;
import com.coob.aframe.base.R;
import com.coob.aframe.util.DateUtil;
import com.coob.modules.tg.domain.Tgry;
import com.coob.modules.tg.service.TgryService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RequestMapping("/tgry")
@Controller
public class TgryController extends BaseController {
    @Resource
    private TgryService tgryService;

    /**
     * 查询未结束的团购业务 下的未成交人员列表
     * 1、登录用户获取区域
     * 2、关联团购信息、项目信息、团购项目信息 获取未结束的团购项目
     * 3、获取未成交的人员信息
     * @param model
     * @return
     */
    @RequestMapping(value = "/doList", method = {RequestMethod.GET, RequestMethod.POST})
    public String doList(String tgmc, String xmmc, Model model) {

        LoginUser currentUser = this.getCurrentUser();

        Map<String, Object> params = new HashMap<String, Object>();
        if(currentUser.getUserType() >= 2){
            params.put("qx", currentUser.getQx());
        }
        params.put("tgmc", tgmc);
        params.put("xmmc", xmmc);
        params.put("cjzt", 1);
        params.put("jzzt", 4);
        this.setParamToSession(params);

        super.offsetPage(1);
        List<Tgry> list = this.tgryService.selectByParams(params);
        PageInfo<Tgry> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("tgmc", tgmc);
        model.addAttribute("xmmc", xmmc);

        return "pages/ywgl/tgry/list";
    }


    /**
     * 分页处理
     * @param model
     * @return
     */
    @RequestMapping(value = "/doPage", method = {RequestMethod.GET, RequestMethod.POST})
    public String doPage(Integer pageNum,Model model) {
        Map<String,Object> params = this.getSessionParam();

        super.offsetPage(pageNum);
        List<Tgry> list = this.tgryService.selectByParams(params);
        PageInfo<Tgry> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("tgmc", params.get("tgmc"));
        model.addAttribute("xmmc", params.get("xmmc"));

        return "pages/ywgl/tgry/list";
    }

    /**
     * 跳转审核页面
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/doCj")
    public String doCj(Integer id, Model model) {
        Tgry tgry = this.tgryService.selectById(id);
        if( tgry.getCjzt() == 2 ) {
            return "redirect:doList";
        }

        tgry.setCjzt(2);
        tgry.setCjr(this.getCurrentUser().getUserName());
        tgry.setCjsj(DateUtil.getCurTime());

        this.tgryService.saveCj(tgry);

        this.alert("确认成交完成");

        return "redirect:doList";
    }

    /**
     * 确认成交
     * @param ryid
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/doPlCj", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doJc(Integer ryid) {
        Tgry tgry = this.tgryService.selectById(ryid);
        if( tgry.getCjzt() == 2 ) {
            return R.ok();
        }

        tgry.setCjzt(2);
        tgry.setCjr(this.getCurrentUser().getUserName());
        tgry.setCjsj(DateUtil.getCurTime());

        this.tgryService.saveCj(tgry);
        return R.ok();
    }
}
