package com.coob.modules.tg.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.LoginUser;
import com.coob.aframe.base.R;
import com.coob.aframe.util.DateUtil;
import com.coob.modules.tg.domain.Tgry;
import com.coob.modules.tg.domain.Tgxm;
import com.coob.modules.tg.domain.Tgxx;
import com.coob.modules.tg.domain.Xmxx;
import com.coob.modules.tg.service.TgryService;
import com.coob.modules.tg.service.TgxmService;
import com.coob.modules.tg.service.TgxxService;
import com.coob.modules.tg.service.XmxxService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@RequestMapping("/tgry/sh")
@Controller
public class TgryShController extends BaseController {
    @Resource
    private TgryService tgryService;
    @Resource
    private TgxxService tgxxService;
    @Resource
    private TgxmService tgxmService;
    @Resource
    private XmxxService xmxxService;


    /**
     * 查询未结束的团购业务 下的待审核的人员列表
     * 1、登录用户获取区域
     * 2、关联团购信息、项目信息、团购项目信息 获取未结束的团购项目
     * 3、获取未审核的人员信息
     * @param model
     * @return
     */
    @RequestMapping(value = "/doList", method = {RequestMethod.GET, RequestMethod.POST})
    public String doList(String tgmc, String xmmc, Model model) {
        //获取本区县需要审核的团购项目
        Integer qx = this.getCurrentUser().getQx();

        Map<String, Object> params = new HashMap<String, Object>();
        params.put("qx", qx);
        params.put("tgmc", tgmc);
        params.put("xmmc", xmmc);
        params.put("shzt", 1);
        params.put("jzzt", 4);
        this.setParamToSession(params);

        super.offsetPage(1);
        List<Tgry> list = this.tgryService.selectByParams(params);
        PageInfo<Tgry> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("tgmc", tgmc);
        model.addAttribute("xmmc", xmmc);

        return "pages/ywgl/tgrySh/list";
    }


    /**
     * 分页处理
     * @param model
     * @return
     */
    @RequestMapping(value = "/doPage", method = {RequestMethod.GET, RequestMethod.POST})
    public String doPage(Integer pageNum,Model model) {
        Map<String,Object> params = this.getSessionParam();

        super.offsetPage(pageNum);
        List<Tgry> list = this.tgryService.selectByParams(params);
        PageInfo<Tgry> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("tgmc", params.get("tgmc"));
        model.addAttribute("xmmc", params.get("xmmc"));

        return "pages/ywgl/tgrySh/list";
    }

    /**
     * 跳转审核页面
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toSh")
    public String toSh(Integer id, Model model) {
        Tgry tgry = this.tgryService.selectById(id);
        Tgxx tgxx = this.tgxxService.selectById(tgry.getTgid());
        Tgxm tgxm = this.tgxmService.selectById(tgry.getTgxmid());
        Xmxx xmxx = this.xmxxService.selectById(tgry.getXmid());

        model.addAttribute("tgry", tgry);
        model.addAttribute("tgxx", tgxx);
        model.addAttribute("tgxm", tgxm);
        model.addAttribute("xmxx", xmxx);

        return "pages/ywgl/tgrySh/sh";
    }

    /**
     * 审核
     * @param tgry
     * @param model
     * @return
     */
    @RequestMapping(value = "/doSh")
    public String doSh(Tgry tgry, Model model) {
        LoginUser currentUser = this.getCurrentUser();
        tgry.setShry(currentUser.getUserName());
        tgry.setShsj(DateUtil.getCurTime());

        if(tgry.getShzt() == 2){
            tgry.setTszt(2);        // 自动推送
            tgry.setTsr(currentUser.getUserName());
            tgry.setTssj(DateUtil.getCurTime());
        }

        this.tgryService.saveSh(tgry);

        this.alert("审核完成");

        return "redirect:doList";
    }


    @ResponseBody
    @RequestMapping(value = "/rSh", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R rSh(Integer ryid) {
        Tgry tgry = this.tgryService.selectById(ryid);

        LoginUser currentUser = this.getCurrentUser();
        tgry.setShzt(2);
        tgry.setShry(currentUser.getUserName());
        tgry.setShsj(DateUtil.getCurTime());

        tgry.setTszt(2);        // 自动推送
        tgry.setTsr(currentUser.getUserName());
        tgry.setTssj(DateUtil.getCurTime());

        this.tgryService.saveSh(tgry);

        return R.ok();
    }
}
