package com.coob.modules.tg.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.LoginUser;
import com.coob.aframe.base.R;
import com.coob.aframe.util.DateUtil;
import com.coob.aframe.util.TemplateExcelUtil;
import com.coob.modules.tg.domain.Tgry;
import com.coob.modules.tg.domain.Tgxm;
import com.coob.modules.tg.domain.Tgxx;
import com.coob.modules.tg.domain.Tgyh;
import com.coob.modules.tg.service.TgryService;
import com.coob.modules.tg.service.TgxmService;
import com.coob.modules.tg.service.TgxxService;
import com.coob.modules.tg.service.TgyhService;
import com.coob.system.domain.Area;
import com.coob.system.service.AreaService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 团购信息(TTgxx)表控制层
 * @author makejava
 * @since 2024-08-01 17:02:08
 */
@Controller
@RequestMapping("/tgxx/gl")
public class TgxxController extends BaseController {
    @Resource
    private AreaService areaService;
    @Resource
    private TgxxService tgxxService;
    @Resource
    private TgxmService tgxmService;
    @Resource
    private TgyhService tgyhService;
    @Resource
    private TgryService tgryService;


    /**
     * 查询托管信息列表
     * 仅查询进行中的托管信息
     *
     * @param gtmc
     * @return
     */
    @RequestMapping(value = "/doList")
    public String doList(String gtmc, Model model) {
        Map<String, Object> params = new HashMap<>();
        params.put("gtmc", gtmc);
        params.put("jzzt", 4);      //仅查询未结束的团购
        super.setParamToSession(params);

        super.offsetPage(1);
        List<Tgxx> list = this.tgxxService.selectByParams(params);
        PageInfo<Tgxx> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("gtmc", gtmc);

        return "pages/ywgl/tgxx/list";
    }

    /**
     * Session分页处理
     *
     * @param pageNum
     * @param model
     * @return
     */
    @RequestMapping(value = "/doPage")
    public String doPage(Integer pageNum, Model model) {
        Map<String, Object> params = this.getSessionParam();

        super.offsetPage(pageNum);
        List<Tgxx> list = this.tgxxService.selectByParams(params);
        PageInfo<Tgxx> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("gtmc", (String) params.get("gtmc"));

        return "pages/ywgl/tgxx/list";
    }


    /**
     * 新增数据页面
     *
     * @param model
     * @return
     */
    @RequestMapping("/toAdd")
    public String toAdd(Model model) {
        Tgxx tgxx = new Tgxx();
        tgxx.setTpbs(0);

        model.addAttribute("tgxx", tgxx);

        return "pages/ywgl/tgxx/add";
    }

    /**
     * 保存新增团购信息
     *
     * @param tgxx
     * @param model
     * @return
     */
    @RequestMapping("/doAdd")
    public String doAdd(Tgxx tgxx, Model model) {
        LoginUser user = this.getCurrentUser();
        tgxx.setTjr(user.getUserName());
        tgxx.setTjsj(DateUtil.getCurTime());

        tgxx.setZt(1);
        tgxx.setXms(0);
        tgxx.setLls(0);
        tgxx.setBmrs(0);
        tgxx.setCjrs(0);
        tgxx.setState(1);

        this.tgxxService.insert(tgxx);

        alert("信息添加成功");

        return "redirect:doList";
    }

    /**
     *
     * @param id
     * @param model
     * @return
     */
    @RequestMapping("/toEdit")
    public String toEdit(Integer id, Model model) {
        Tgxx tgxx = this.tgxxService.selectById(id);

        model.addAttribute("tgxx", tgxx);

        return "pages/ywgl/tgxx/edit";
    }

    /**
     *
     * @param tgxx
     * @param model
     * @return
     */
    @RequestMapping("/doEdit")
    public String doEdit(Tgxx tgxx, Model model) {
        this.tgxxService.update(tgxx);

        alert("信息保存成功");

        return "redirect:doList";
    }

    /**
     * 查看团购详情
     * @param id
     * @param model
     * @return
     */
    @RequestMapping("/toView")
    public String toView(Integer id, Model model) {
        //查询托管信息
        Tgxx tgxx = this.tgxxService.selectById(id);

        model.addAttribute("tgxx", tgxx);

        return "pages/ywgl/tgxx/view";
    }

    /**
     * 查看参团项目信息
     * @param qx
     * @param xmmc
     * @param model
     * @return
     */
    @RequestMapping("/xmList")
    public String xmList(Integer tgid, Integer qx, String xmmc, Model model) {
        Tgxx tgxx = this.tgxxService.selectById(tgid);
        List<Tgxm> xmList = this.tgxmService.selectListXmByTgid(tgid, qx, xmmc, "1,2");
        List<Area> qyList = this.areaService.selectList();

        model.addAttribute("tgxx", tgxx);
        model.addAttribute("xmList", xmList);
        model.addAttribute("qyList", qyList);
        model.addAttribute("tgid", tgid);
        model.addAttribute("qx", qx);
        model.addAttribute("xmmc", xmmc);

        return "pages/ywgl/tgxx/xmList";
    }


    /**
     * 发布活动，开始报名团购
     * @param id
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/fabu", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R fabu(Integer id) {
        Tgxx tgxx = this.tgxxService.selectById(id);

        if( tgxx.getZt() == 2 ) {
            return R.ok("活动已发布");
        }
        if( tgxx.getZt() != 1 ) {
            return R.error("团购活动状态异常, 无法发布");
        }

        //查询参数项目
        List<Tgxm> tgxmList = this.tgxmService.selectListXmByTgid(id, null, null, "1,2");

        //检查是否添加项目
        if( tgxmList == null || tgxmList.size() == 0 ) {
            return R.error("没有添加项目信息, 无法发布");
        }

        //检查项目是否都审核通过
        for( Tgxm tx : tgxmList ){
            if( tx.getShzt() == 1 ) {
                return R.error(tx.getXmmc() + " 未审核, 无法发布");
            }
            if(tx.checkYh()){
                return R.error(tx.getXmmc() + " 优惠未填写, 无法发布");
            }
        }

        Tgxx tg = new Tgxx();
        tg.setId(id);
        tg.setZt(2);
        tg.setFbr(this.getCurrentUser().getUserName());
        tg.setFbsj(DateUtil.getCurTime());
        this.tgxxService.update(tg);

        return R.ok("活动发布成功");
    }

    /**
     * 活动结束（不可报名团购）
     * @param id
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/jieshu", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R jieshu(Integer id, Integer zt) {
        Tgxx tg = new Tgxx();
        tg.setId(id);
        tg.setZt(zt);
        if (zt == 4) {
            tg.setJsr(this.getCurrentUser().getUserName());
            tg.setJssj(DateUtil.getCurTime());
        }
        this.tgxxService.update(tg);

        return R.ok("活动操作完成");
    }


    /**
     * 保存优惠活动
     * @param ksrs
     * @param jzrs
     * @param yhhd
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/saveYh", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R saveYh(Integer tgid, Integer xmid, Integer ksrs, Integer jzrs, String yhhd) {

        Tgyh tgyh = new Tgyh();
        tgyh.setTgid(tgid);
        tgyh.setXmid(xmid);
        tgyh.setKsrs(ksrs);
        tgyh.setJzrs(jzrs);
        tgyh.setYhhd(yhhd);
        tgyh.setCzr(this.getCurrentUser().getUserName());
        tgyh.setCzsj(DateUtil.getCurTime());
        tgyh.setState(1);

        List<Tgyh> tgyhs = this.tgyhService.selectListByTgidAndXmid(tgid, xmid);
        for (Tgyh item : tgyhs) {
           boolean cfjc = item.checkCfjc(tgyh.getKsrs(),tgyh.getJzrs());
           if(cfjc){
               return R.error("参团人数重复或者交叉，请确认");
           }
        }

        this.tgyhService.insert(tgyh);

        List<Tgyh> list = this.tgyhService.selectListByTgidAndXmid(tgid,xmid);

        return R.ok("信息保存成功").put("list", list);
    }


    /**
     * 查看人员列表
     * @param txid
     * @param model
     * @return
     */
    @RequestMapping("/ryList")
    public String ryList(Integer txid, Model model){
        Tgxm tgxm = this.tgxmService.selectById(txid);
        List<Tgry> ryList = this.tgryService.selectListByTgxmid(txid, null);

        model.addAttribute("tgxm", tgxm);
        model.addAttribute("ryList", ryList);

        return "pages/ywgl/tgxx/ryList";
    }


    /**
     * 房屋列表导出excel文件
     * @param tgid
     * @param response
     * @throws Exception
     */
    @RequestMapping("/exportExcel")
    @ResponseBody
    public void exportExcel(Integer tgid, HttpServletResponse response) throws Exception{
        //查询数据
        List<Tgxm> xmList = this.tgxmService.selectXmListForExport(tgid);

        Map<String, Object> beans = new HashMap<String, Object>();
        List<HashMap<String, Object>> list = new ArrayList<>();

        int xh = 0;
        for( Tgxm xm: xmList ){
            xh++;
            HashMap<String, Object> o = new HashMap<String, Object>();
            o.put("xh", xh);
            o.put("xmmc", xm.getXmmc());
            o.put("qxmc", xm.getQxmc());
            o.put("qymc", xm.getQymc());
            o.put("kprq", xm.getKpsj());
            o.put("jfrq", xm.getJhjfrq());
            o.put("jg", xm.getXsjg());
            o.put("yh3", xm.getYh3());
            o.put("yh5", xm.getYh5());
            o.put("yh10", xm.getYh10());
            o.put("yhqt", xm.getYhqt());
            list.add(o);
        }
        beans.put("list", list);

        //模板名称
        String template = "lplist.xlsx";
        //导出文件名称
        String fileName = "团购楼盘列表";

        try {
            TemplateExcelUtil.downLoadExcel(fileName, template, beans, response);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}