package com.coob.modules.tg.service;

import java.util.List;
import java.util.Map;

import com.coob.aframe.util.DateUtil;
import com.coob.modules.api.vo.BmjxVo;
import com.coob.modules.tg.dao.TgxmDao;
import com.coob.modules.tg.dao.TgxxDao;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.coob.modules.tg.domain.Tgry;
import com.coob.modules.tg.dao.TgryDao;

@Service
@Transactional
public class TgryService {
	@Autowired
	private TgryDao tgryDao;
	@Autowired
	private TgxxDao tgxxDao;
	@Autowired
	private TgxmDao tgxmDao;


	/**
	 * 保存报名信息
	 * @param tgry
	 * @return
	 */
	public int saveBm(Tgry tgry){
		// 默认审核成功 推送成功
		tgry.setShzt(2);
		tgry.setTszt(2);
		tgry.setShsj(DateUtil.getCurTime());
		tgry.setTssj(DateUtil.getCurTime());

		//保存人员信息
		int flag = this.tgryDao.insert(tgry);
		//团购信息 报名人数统计 统计
		this.tgxxDao.updateBmrs(tgry.getTgid());
		//项目报名数增加
		this.tgxmDao.updateBmrsById(tgry.getTgxmid());

		return flag;
	}


	/**
	 * 保存审核信息
	 * @param tgry
	 * @return
	 */
	public int saveSh(Tgry tgry){
		//保存信息
		int flag = this.tgryDao.update(tgry);

		//审核通过
		if( tgry.getShzt() == 2){
			//团购信息 报名人数统计 统计
			this.tgxxDao.updateBmrs(tgry.getTgid());
			//项目报名数增加
			this.tgxmDao.updateBmrsById(tgry.getTgxmid());
		}

		return flag;
	}


	/**
	 * 保存成交信息
	 * @param tgry
	 * @return
	 */
	public int saveCj(Tgry tgry) {
		//保存信息
		int flag = this.tgryDao.update(tgry);

		//更新团购成交人
		this.tgxxDao.updateCjrs(tgry.getTgid());

		//更新项目成交人
		this.tgxmDao.updateCjrsById(tgry.getTgxmid());

		return flag;
	}


	/**
	 * 逻辑删除
	 * @param id
	 * @return
	 */
	public int deleteById(Integer id){
		int flag = this.tgryDao.deleteById(id);
		return flag;
	}


	/**
	 * 物理删除
	 * @param id
	 * @return
	 */
	public int physicalDeleteById(Integer id){
		int flag = this.tgryDao.physicalDeleteById(id);
		return flag;
	}


	/**
	 * 根据id查询信息
	 * @param id
	 * @return
	 */
	public Tgry selectById(Integer id){
		return this.tgryDao.selectById(id);
	}

	/**
	 * 根据 tgid
	 * @param tgid
	 * @return
	 */
	public List<Tgry> selectListByTgid(Integer tgid) {
		return this.tgryDao.selectListByTgid(tgid);
	}

	/**
	 * 根据 tgxmid查询团购人员信息
	 * @return
	 */
	public List<Tgry> selectListByTgxmid(Integer tgxmid, Integer shzt){
		return this.tgryDao.selectListByTgxmid(tgxmid, shzt);
	}

	/**
	 * 报名检查，同一活动、项目，同一手机号只能有1条数据
	 * @param tgid
	 * @param xmid
	 * @param sjhm
	 * @return
	 */
	public Tgry selectForCheck(Integer tgid, Integer xmid, String sjhm){
		Tgry tgry = this.tgryDao.selectForCheck(tgid, xmid, sjhm);
		return tgry;
	}

	/**
	 * 根据手机号，查询团购报名记录，用于微信展示
	 * @param tgid
	 * @param sjhm
	 * @return
	 */
	public List<BmjxVo> selectListBySjhmForWx(Integer tgid, String sjhm) {
		List<BmjxVo> list = this.tgryDao.selectListBySjhmForWx(tgid, sjhm);
		return list;
	}

	/**
	 * 条件查询列表
	 * @param params
	 * @return
	 */
	public List<Tgry> selectByParams(Map<String,Object> params){
		return this.tgryDao.selectByParams(params);
	}

}
