package com.coob.modules.tg.service;

import com.coob.modules.api.vo.GdTgxmVo;
import com.coob.modules.tg.dao.TgxmDao;
import com.coob.modules.tg.dao.TgxxDao;
import com.coob.modules.tg.dao.TgyhDao;
import com.coob.modules.tg.domain.Tgxm;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
@Transactional
public class TgxmService {
	@Resource
	private TgxmDao tgxmDao;
	@Resource
	private TgxxDao tgxxDao;
	@Resource
	private TgyhDao tgyhDao;


	/**
	 * 新增
	 * @param tgxm
	 * @return
	 */
	public int insert(Tgxm tgxm){
		int flag = this.tgxmDao.insert(tgxm);
		return flag;
	}
	/**
	 * 新增
	 * @param tgxm
	 * @return
	 */
	public int update(Tgxm tgxm){
		int flag = this.tgxmDao.update(tgxm);
		return flag;
	}

	/**
	 * 更新浏览数
	 *  包含 团购活动、托管项目
	 * @return
	 */
	public int updateLlsByTgidAndXmid(Integer tgid, Integer xmid){
		int flag = this.tgxxDao.updateLls(tgid);
		flag += this.tgxmDao.updateLlsByTgidAndXmid(tgid, xmid);
		return flag;
	}

	/**
	 * 托管项目审核
	 * @param tgxm
	 * @return
	 */
	public int saveCx(Tgxm tgxm){
		//修改审核信息
		int flag = this.tgxmDao.update(tgxm);
		//更新团购的项目数
		this.tgxxDao.updateXms(tgxm.getTgid());
		return flag;
	}

	/**
	 * 托管项目审核
	 * @param tgxm
	 * @return
	 */
	public int saveShenhe(Tgxm tgxm){
		//修改审核信息
		int flag = this.tgxmDao.update(tgxm);

		int shzt = tgxm.getShzt();

		if( shzt == 2 ) {
			//更新团购的项目数
			this.tgxxDao.updateXms(tgxm.getTgid());
		}

		return flag;
	}


	/**
	 * 逻辑删除
	 * @param id
	 * @return
	 */
	public int deleteById(Integer id){
		Tgxm tgxm = this.tgxmDao.selectById(id);
		int flag = this.tgxmDao.deleteById(id);
		this.tgxxDao.updateXms(tgxm.getTgid());
		return flag;
	}

	/**
	 * 按项目ID，统计参加活动数量（仅统计审核通过的）
	 * @param xmid
	 * @return
	 */
	public int selectCountByXmid(Integer xmid){
		int count = this.tgxmDao.selectCountByXmid(xmid);
		return count;
	}

	/**
	 * 根据id查询信息
	 * @param id
	 * @return
	 */
	public Tgxm selectById(Integer id){
		return this.tgxmDao.selectById(id);
	}

    /**
     * 根据团购id和项目id查询团购项目
     * @param tgid
     * @param xmid
     * @return
     */
    public Tgxm selectByTgidAndXmid(Integer tgid, Integer xmid) {
        return this.tgxmDao.selectByTgidAndXmid(tgid,xmid);
    }

	/**
	 * 根据团购ID，查询信息，并级联查询项目信息
	 * @param tgid
	 * @param shzts
	 * @return
	 */
	public List<Tgxm> selectListXmByTgid(Integer tgid, Integer qx, String xmmc, String shzts){
		List<Tgxm> list = this.tgxmDao.selectListXmByTgid(tgid, qx, xmmc, shzts);
		return list;
	}

	/**
	 * 根据项目ID，查询信息，并级联查询团购信息
	 * @param xmid
	 * @param shzt
	 * @return
	 */
	public List<Tgxm> selectListTgByXmid(Integer xmid, Integer shzt){
		List<Tgxm> list = this.tgxmDao.selectListTgByXmid(xmid, shzt);
		return list;
	}

	/**
	 * 根据企业和团购信息id 查询企业名下的团购项目
	 * @param tgid
	 * @param qyid
	 * @return
	 */
	public List<Tgxm> selectListXmByTgidAndQyid(Integer tgid, Integer qyid) {
		List<Tgxm> list = this.tgxmDao.selectListXmByTgidAndQyid(tgid,qyid);
		return list;
	}
	/**
	 * 条件查询列表
	 * @param params
	 * @return
	 */
	public List<Tgxm> selectByParams(Map<String,Object> params){
		return this.tgxmDao.selectByParams(params);
	}

	/**
	 * 根据团购id，查询已经审核通过的项目信息，用于导出Excel
	 * @param tgid
	 * @return
	 */
	public List<Tgxm> selectXmListForExport(Integer tgid){
		return this.tgxmDao.selectXmListForExport(tgid);
	}


	/**
	 * 获取报名人数最多的楼盘
	 * 获取未结束的团购2、审批通过2（注意未撤销的-2） 团购项目 报名人数前十的项目信息
	 * @return
	 */
    public List<GdTgxmVo> selectLpsByBmrs() {
		return this.tgxmDao.selectLpsByBmrs();
    }
}
