package com.coob.system.controller;

import com.coob.aframe.base.BaseController;
import com.coob.system.domain.Depart;
import com.coob.system.service.AreaService;
import com.coob.system.service.DepartService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 部门信息管理
 */
@Controller
@RequestMapping("/sys/depart")
public class DepartController extends BaseController {
    @Resource
    private DepartService departService;
    @Resource
    private AreaService areaService;


    /**
     * 查询部门信息列表
     * @param bmmc
     * @return
     */
    @RequestMapping(value = "/doList")
    public String doList(String bmmc, Integer pageNum, Model model) {
        System.out.println(">>>>>> bmmc=" + bmmc);
        Map<String, Object> params = new HashMap<>();
        params.put("bmmc", bmmc);
        params.put("state", 1);
        super.setParamToSession(params);

        super.offsetPage(pageNum);
        List<Depart> list = this.departService.selectByParams(params);
        PageInfo<Depart> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("bmmc", bmmc);

        return "pages/system/depart/list";
    }


    /**
     * 信息新增
     * @param model
     * @return
     */
    @RequestMapping(value = "/toAdd")
    public String toAdd(Model model) {
        Depart depart = new Depart();

        model.addAttribute("depart", depart);
        model.addAttribute("qxlist", this.areaService.selectList());

        return "pages/system/depart/add";
    }

    /**
     * 保存新增的信息
     * @param depart
     * @param model
     * @return
     */
    @RequestMapping(value = "/doAdd")
    public String doAdd(Depart depart, Model model) {
        if( depart.getLb() == 1 ) {
            depart.setQx(0);
        }
        depart.setSn(1);
        depart.setState(1);
        this.departService.insert(depart);
        alert("信息保存成功");

        return toEdit(depart.getId(), model);
    }


    /**
     * 信息编辑
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toEdit")
    public String toEdit(Integer id, Model model) {
        Depart depart = this.departService.selectById(id);

        model.addAttribute("depart", depart);
        model.addAttribute("qxlist", this.areaService.selectList());

        return "pages/system/depart/edit";
    }


    /**
     * 保存修改的信息
     * @param depart
     * @param model
     * @return
     */
    @RequestMapping(value = "/doEdit")
    public String doEdit(Depart depart, Model model) {
        if( depart.getLb() == 1 ) {
            depart.setQx(0);
        }
        depart.setSn(1);

        this.departService.update(depart);
        alert("信息保存成功");

        depart = this.departService.selectById(depart.getId());

        model.addAttribute("depart", depart);
        model.addAttribute("qxlist", this.areaService.selectList());

        return "pages/system/depart/edit";
    }


    /**
     * 删除信息
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/doDel")
    public String doDel(Integer id, Model model) {
        this.departService.deleteById(id);
        alert("信息删除成功");

        return "redirect:doList";
    }

}
