package com.coob.system.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.LoginUser;
import com.coob.aframe.util.DateUtil;
import com.coob.modules.tg.domain.Qyxx;
import com.coob.modules.tg.service.QyxxService;
import com.coob.system.domain.Depart;
import com.coob.system.domain.Menu;
import com.coob.system.domain.User;
import com.coob.system.service.DepartService;
import com.coob.system.service.RoleService;
import com.coob.system.service.UserService;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import javax.annotation.Resource;
import java.util.List;


/**
 * @Author: Gao
 * @Date: 2024/1/30/17:41
 * @Description: 用户登录
 */
@Controller
@RequestMapping("/")
public class LoginController extends BaseController {
    @Resource
    private DepartService departService;
    @Resource
    private UserService userService;
    @Resource
    private RoleService roleService;
    @Resource
    private QyxxService qyxxService;


    /**
     * 登陆页面
     * @return
     */
    @RequestMapping(value = "/login", method={RequestMethod.POST, RequestMethod.GET}, produces = "application/json;charset=utf-8") // 防止json传输出现乱码
    public String login(String account, String password, Model model) {
        System.out.println( DateUtil.curT() + " > 用户登录：account=" + account);

        //验证账号密码输入
        if( account == null || account.length() == 0 || account == null || account.length() == 0){
            return "login";
        }

        //判断账户
        User user = this.userService.selectByDlzh(account);
        if( user == null ){
            model.addAttribute("resultMsg", "账户不存在");
            return "login";
        }

        //判断密码
        String pwd = user.enCodePwd(password);
        if( !pwd.equals(user.getDlmm())) {
            model.addAttribute("resultMsg", "登录密码错误");
            return "login";
        }

        LoginUser loginUser = new LoginUser();
        loginUser.setUserInfo(user);

        Integer bmid = user.getBmid();
        if( bmid != null ) {
            if( user.getLb() < 3 ) {
                Depart depart = this.departService.selectById(bmid);
                if (depart != null) {
                    loginUser.setDepartInfo(depart);
                }
            } else {
                Qyxx qyxx = this.qyxxService.selectById(bmid);
                if (qyxx != null) {
                    loginUser.setQyxxInfo(qyxx);
                }
            }
        }

        //建立Session
        this.session = this.request.getSession(true);
        super.setCurrentUser(loginUser);

        //查询操作菜单
        String menuStr =  this.menuStr(loginUser);

        model.addAttribute("loginUser", loginUser);
        model.addAttribute("menuStr", menuStr);

        return "main";
    }


    @GetMapping("/logout")
    public String logout(Model model) {
        super.removeCurrentUser();
        return "login";
    }


    /**
     * 获取登录账户权限菜单
     * @param user
     * @return
     */
    private String menuStr(LoginUser user){
        StringBuffer menuStr = new StringBuffer();
        List<Menu> mList = null;

        if (user.getGlybs() == 1) {
            // 超级管理员获取全部
            mList = this.roleService.selectMenuListByType(0);
        } else {
            mList = this.roleService.selectMenuListByUserId(user.getUserId());
        }

        if( mList != null ){
            for( Menu m : mList){
                if( m.getParentId() == 0 ){
                    menuStr.append("<div title= \""+ m.getMenuName()+"\" data-options=\"iconCls:'fa fa-arrow-right'\" style=\"padding: 0px;overflow:auto;\">");
                    menuStr.append("<ul class=\"easyui-tree\">");
                    for( Menu c : mList ){
                        if( c.getParentId().intValue() == m.getId().intValue() ){
                            menuStr.append( "<li><div style=\"width:100%;hight:100%\"><a href=\"javascript:addTab('"+c.getMenuName()+"','"+c.getUrl()+"','fa fa-plus')\">"
                                    +c.getMenuName()+"</a></div></li> ");
                        }
                    }
                    menuStr.append("</ul></div>");
                }
            }
        }

        return menuStr.toString();
    }

}
