package com.coob.system.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.R;
import com.coob.aframe.util.DateUtil;
import com.coob.modules.tg.service.QyxxService;
import com.coob.system.domain.User;
import com.coob.system.domain.UserRole;
import com.coob.system.service.RoleService;
import com.coob.system.service.UserService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 企业用户管理
 */
@Controller
@RequestMapping("/sys/qyuser")
public class QyUserController extends BaseController {
    @Resource
    private QyxxService qyxxService;
    @Resource
    private UserService userService;
    @Resource
    private RoleService roleService;


    /**
     * 查询部门信息列表
     * @param xm
     * @return
     */
    @RequestMapping(value = "/doList")
    public String doList(String xm, String qymc, Integer pageNum, Model model) {
        Map<String, Object> params = new HashMap<>();
        params.put("xm", xm);
        params.put("qymc", qymc);
        params.put("lb", 3);

        super.offsetPage(pageNum);
        List<User> list = this.userService.selectByParams(params);
        PageInfo<User> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("xm", xm);
        model.addAttribute("qymc", qymc);

        return "pages/system/qyuser/list";
    }


    /**
     * 进入用户新增页面
     * @param model
     * @return
     */
    @RequestMapping(value = "/toAdd")
    public String toAdd(Model model){
        User user = new User();

        model.addAttribute("user", user);
        model.addAttribute("qyList", this.qyxxService.selectListAll());
        model.addAttribute("roleList", this.roleService.selectRoleListByType(1));

        return "pages/system/qyuser/add";
    }

    /**
     * 保存用户信息
     * @param user
     * @param model
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/doAdd", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doAdd(User user, Model model) {
        User u = this.userService.selectByDlzh(user.getDlzh());
        if( u != null ) {
            return R.error("登录账号重复");
        }

        user.setLb(3);
        user.setQx(0);
        if( user.getUkeybs() == null ) {
            user.setUkeybs(0);
        }
        user.setGlybs(0);
        user.setZcsj(DateUtil.getCurTime());
        user.setDlcs(0);
        user.setState(1);

        user.setDefaultPwd();

        this.userService.insert(user);

        return R.ok("信息保存成功").put("user", user);
    }


    /**
     * 进入用户修改页面
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toEdit")
    public String toEdit(Integer id, Model model) {
        User user = this.userService.selectById(id);

        List<UserRole> urList = this.userService.selectListUserRoleByUserId(id);
        if( urList != null && urList.size() > 0 ) {
            user.setRoleId(urList.get(0).getRoleId());
        }

        model.addAttribute("user", user);
        model.addAttribute("qyList", this.qyxxService.selectListAll());
        model.addAttribute("roleList", this.roleService.selectRoleListByType(1));

        return "pages/system/qyuser/edit";
    }

    /**
     * 修改用户信息
     * @param user
     * @param model
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/doEdit", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doEdit(User user, Model model) {
        User u = this.userService.selectByDlzh(user.getDlzh());
        if( u != null && !u.getId().equals(user.getId()) ) {
            return R.error("登录账号重复");
        }

        if( user.getUkeybs() == null ) {
            user.setUkeybs(0);
        }

        this.userService.update(user);

        return R.ok("信息保存成功").put("user", user);
    }


    /**
     * 删除用户信息
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/doDel")
    public String doDel(Integer id, Model model) {
        this.userService.deleteById(id);
        alert("信息删除成功");

        return "redirect:doList";
    }


    /**
     * 显示详情
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toView")
    public String toView(Integer id, Model model) {
        User user = this.userService.selectById(id);
        model.addAttribute("user", user);

        return "pages/system/qyuser/view";
    }

}
