package com.coob.system.controller;

import com.coob.aframe.base.BaseController;
import com.coob.system.domain.Depart;
import com.coob.system.domain.Menu;
import com.coob.system.domain.Role;
import com.coob.system.service.AreaService;
import com.coob.system.service.DepartService;
import com.coob.system.service.RoleService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 部门信息管理
 */
@Controller
@RequestMapping("/sys/role")
public class RoleController extends BaseController {
    @Resource
    private RoleService roleService;


    /**
     * 查询角色信息列表
     * @param roleName
     * @param roleType
     * @param pageNum
     * @param model
     * @return
     */
    @RequestMapping(value = "/doList")
    public String doList(String roleName, Integer roleType, Integer pageNum, Model model) {
        Map<String, Object> params = new HashMap<>();
        params.put("roleName", roleName);
        params.put("roleType", roleType);

        super.offsetPage(pageNum);
        List<Role> list = this.roleService.selectByParams(params);
        PageInfo<Role> pageInfo = new PageInfo<>(list);

        model.addAttribute("pageInfo", pageInfo);
        model.addAttribute("roleName", roleName);
        model.addAttribute("roleType", roleType);

        return "pages/system/role/list";
    }


    /**
     * 信息新增
     * @param model
     * @return
     */
    @RequestMapping(value = "/toAdd")
    public String toAdd(Model model) {
        Role role = new Role();
        role.setRoleType(0);
        model.addAttribute("role", role);
        model.addAttribute("menuStr", this.toMenu(null, 0));

        return "pages/system/role/add";
    }

    /**
     * 保存新增的信息
     * @param role
     * @param selMenuIds
     * @param model
     * @return
     */
    @RequestMapping(value = "/doAdd")
    public String doAdd(Role role, Integer[] selMenuIds, Model model) {
        this.roleService.insertRole(role, selMenuIds);
        alert("信息保存成功");

        return toEdit(role.getId(), model);
    }


    /**
     * 信息编辑
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toEdit")
    public String toEdit(Integer id, Model model) {
        Role role = this.roleService.selectRoleById(id);

        model.addAttribute("role", role);
        model.addAttribute("menuStr", this.toMenu(id, role.getRoleType()));

        return "pages/system/role/edit";
    }


    /**
     * 保存修改的信息
     * @param role
     * @param selMenuIds
     * @param model
     * @return
     */
    @RequestMapping(value = "/doEdit")
    public String doEdit(Role role, Integer[] selMenuIds, Model model) {
        this.roleService.updateRole(role, selMenuIds);
        alert("信息保存成功");

        model.addAttribute("role", role);
        model.addAttribute("menuStr", this.toMenu(role.getId(), role.getRoleType()));

        return "pages/system/role/edit";
    }


    /**
     * 删除信息
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/doDel")
    public String doDel(Integer id, Model model) {
        this.roleService.deleteRoleById(id);
        alert("信息删除成功");

        return "redirect:doList";
    }


    /**
     * 显示详细信息
     * @param id
     * @param model
     * @return
     */
    @RequestMapping("/toView")
    public String toView(Integer id, Model model){
        Role role = this.roleService.selectRoleById(id);

        String contextPath = this.request.getServletContext().getContextPath();

        List<Menu> menuList = this.roleService.selectMenuListByRoleId(id);
        StringBuffer menus = new StringBuffer("<script type=\"text/javascript\">\n")
                .append("d = new dTree('d', '"+contextPath+"/static/js/dtree/img', false);\n")
                .append("d.add(0,-1,'功能列表');\n");
        if( menuList != null ){
            for (Menu menu : menuList) {
                Integer pId = menu.getParentId();
                Integer mId = menu.getId();
                menus.append("d.add(" + mId + "," + pId + ",'"+ menu.getMenuName()+ "');\n");
            }
        }
        menus.append("document.write(d);\n");
        menus.append("</script>");

        model.addAttribute("role", role);
        model.addAttribute("menuStr", menus.toString());

        return "pages/system/role/view";
    }


    /**
     * 切换角色类别时调佣
     * @param role
     * @param page
     * @param model
     * @return
     */
    @RequestMapping("/menu")
    public String menu(Role role, String page, Model model){
        model.addAttribute("role", role);
        model.addAttribute("menuStr", this.toMenu(role.getId(), role.getRoleType()));

        return "pages/system/role/"+page;
    }


    /**
     * 查询菜单列表，拼接Dtree字符串
     * @param roleId
     * @param type
     * @return
     */
    private String toMenu(Integer roleId, Integer type){
        String contextPath = this.request.getServletContext().getContextPath();

        StringBuffer menus = new StringBuffer("<script type=\"text/javascript\">\n")
                .append("d = new dTree('d', '"+contextPath+"/static/js/dtree/img', false);\n")
                .append("d.add(0,-1,'功能列表');\n");

        List<Menu> allList = this.roleService.selectMenuListByType(type);
        List<Menu> menuList =  null;

        if( roleId != null ) {
            menuList = this.roleService.selectMenuListByRoleId(roleId);
        }

        if( allList != null ){
            for(Menu  menu : allList ){
                Integer id = menu.getId();
                Integer pId = menu.getParentId();
                menus.append("d.add(" + id + ","+ pId + ",")
                        .append("'<input type=\"checkbox\" id=\"menu"+pId+"_"+id+"\" name=\"selMenuIds\" value=\""+id+"\" onclick=\"checkMenu("+pId+","+id+")\" ");

                menu.setSelected(false);
                if( menuList != null && menuList.size()> 0){
                    for( Menu m : menuList ){
                        if( m.getId().equals(menu.getId())){
                            menu.setSelected(true);
                            menus.append(" checked=\"checked\" ");
                            break;
                        }
                    }
                }
                menus.append("/> " + menu.getMenuName()+ "');\n");
            }
        }

        menus.append("document.write(d);\n");
        menus.append("d.openAll();\n");
        menus.append("</script>");

        return menus.toString();
    }
}
