package com.coob.system.controller;

import com.coob.aframe.base.BaseController;
import com.coob.aframe.base.LoginUser;
import com.coob.aframe.base.R;
import com.coob.aframe.util.DateUtil;
import com.coob.system.domain.Depart;
import com.coob.system.domain.User;
import com.coob.system.domain.UserRole;
import com.coob.system.service.DepartService;
import com.coob.system.service.RoleService;
import com.coob.system.service.UserService;
import com.github.pagehelper.PageInfo;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 用户信息管理
 */
@Controller
@RequestMapping("/sys/sy")
public class ShouyeController extends BaseController {
    @Resource
    private DepartService departService;
    @Resource
    private UserService userService;
    @Resource
    private RoleService roleService;


    /**
     * 进入首页
     * @param model
     * @return
     */
    @RequestMapping(value = "/toSy")
    public String toSy(Model model) {
        LoginUser user = this.getCurrentUser();

        return "pages/system/user/list";
    }


    /**
     * 进入用户新增页面
     * @param model
     * @return
     */
    @RequestMapping(value = "/toAdd")
    public String toAdd(Model model){
        List<Depart> departList = this.departService.selectListAll();
        User user = new User();
        user.setDefaultPwd();

        model.addAttribute("user", user);
        model.addAttribute("departList", departList);
        model.addAttribute("roleList", this.roleService.selectRoleListByType(0));

        return "pages/system/user/add";
    }

    /**
     * 保存用户信息
     * @param user
     * @param model
     * @return
     */
    @RequestMapping(value = "/doAdd")
    public String doAdd(User user, Model model) {
        Depart depart = this.departService.selectById(user.getBmid());

        user.setLb(depart.getLb());
        user.setQx(depart.getQx());
        if( user.getUkeybs() == null ) {
            user.setUkeybs(0);
        }
        user.setGlybs(0);
        user.setZcsj(DateUtil.getCurTime());
        user.setDlcs(0);
        user.setState(1);

        user.setDefaultPwd();

        this.userService.insert(user);
        alert("信息保存成功");

        return toEdit(user.getId(), model);
    }


    /**
     * 进入用户修改页面
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toEdit")
    public String toEdit(Integer id, Model model) {
        List<Depart> departList = this.departService.selectListAll();
        User user = this.userService.selectById(id);

        List<UserRole> urList = this.userService.selectListUserRoleByUserId(id);
        if( urList != null && urList.size() > 0 ) {
            user.setRoleId(urList.get(0).getRoleId());
        }

        model.addAttribute("user", user);
        model.addAttribute("departList", departList);
        model.addAttribute("roleList", this.roleService.selectRoleListByType(0));

        return "pages/system/user/edit";
    }

    /**
     * 修改用户信息
     * @param user
     * @param model
     * @return
     */
    @RequestMapping(value = "/doEdit")
    public String doEdit(User user, Model model) {
        Depart depart = this.departService.selectById(user.getBmid());

        user.setLb(depart.getLb());
        user.setQx(depart.getQx());
        if( user.getUkeybs() == null ) {
            user.setUkeybs(0);
        }

        this.userService.update(user);
        alert("信息保存成功");

        return toEdit(user.getId(), model);
    }


    /**
     * 删除用户信息
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/doDel")
    public String doDel(Integer id, Model model) {
        this.userService.deleteById(id);
        alert("信息删除成功");

        return "redirect:doList";
    }


    /**
     * 显示详情
     * @param id
     * @param model
     * @return
     */
    @RequestMapping(value = "/toView")
    public String toView(Integer id, Model model) {
        User user = this.userService.selectById(id);
        model.addAttribute("user", user);

        return "pages/system/user/view";
    }


    /**
     * 重置用户密码
     * @param id
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/rePwd", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R rePwd(Integer id) {
        User user = new User();
        user.setId(id);
        user.setDefaultPwd();
        this.userService.update(user);

        return R.ok();
    }


    /**
     * 进入修改密码页面
     * @param model
     * @return
     */
    @RequestMapping(value = "/toPwd")
    public String toPwd(Model model) {
        return "pages/system/user/pwd";
    }

    /**
     * 个人修改密码
     * @param opwd
     * @param npwd
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/doPwd", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R doPwd(String opwd, String npwd) {
        LoginUser curU = this.getCurrentUser();

        User user = this.userService.selectById(curU.getUserId());
        String pwd = user.enCodePwd(opwd);
        if( !pwd.equals(user.getDlmm()) ) {
            return R.error("原登录密码错误");
        }

        pwd = user.enCodePwd(npwd);
        User u = new User();
        u.setId(user.getId());
        u.setDlmm(pwd);
        this.userService.update(u);

        return R.ok("密码修改成功");
    }


    /**
     * 检查登录账号是否重复
     * @param dlzh
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/check", method = { RequestMethod.POST, RequestMethod.GET }, produces="application/json;charset=utf8")
    public R check(String dlzh) {
        User user = this.userService.selectByDlzh(dlzh);
        Integer userId = 0;
        if( user != null ) {
            userId = user.getId();
        }

        return R.ok().put("userId", userId);
    }
}
