package com.coob.system.service;

import com.coob.system.dao.DicItemDao;
import com.coob.system.dao.DicTypeDao;
import com.coob.system.domain.DicItem;
import com.coob.system.domain.DicType;
import org.apache.ibatis.session.RowBounds;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * 字典管理Service
 * @author JK.Sun
 *
 */
@Service
@Transactional
public class DicService {
	@Autowired
	private DicTypeDao dicTypeDao;
	@Autowired
	private DicItemDao dicItemDao;

	public DicType selectById(Integer id){
		return this.dicTypeDao.selectById(id);
	}

	public List<DicType> selectByParams(Map<String,Object> params){
		return this.dicTypeDao.selectByParams(params);
	}

	public List<DicType> selectByParams(Map<String,Object> params, RowBounds rowBounds){
		return this.dicTypeDao.selectByParams(params, rowBounds);
	}

	
	/**
	 * 保存字典项
	 * @param dicItem
	 * @return
	 */
	public int insertItem(DicItem dicItem){
		dicItem.setVersion(1);
		dicItem.setState(1);
		this.dicItemDao.insert(dicItem);

		return 1;
	}


	public int updateItem(DicItem dicItem){
		this.dicItemDao.update(dicItem);
		return 1;
	}
	
	public int delItemById(Integer itemId){
		this.dicItemDao.deleteById(itemId);
		return 1;
	}

	
	public DicItem selectItemById(Integer itemId){
		return this.dicItemDao.selectById(itemId);
	}
	
	
	/**
	 * 根据类别查询字典项
	 * @param typeCode
	 * @return
	 */
	public List<DicItem> selectItemByType(String typeCode){
		List<DicItem> list = this.dicItemDao.selectByTypeCode(typeCode);
		return list;
	}

	public List<DicItem> selectItemAllList(){
		return this.dicItemDao.selectAll();
	}


	/**
	 * 查询人员类别列表
	 * @return
	 */
	public List<DicItem> selectItemRyLb() {
		List<DicItem> list = this.dicItemDao.selectByTypeCode("RyLb");
		return list;
	}
}
