package com.coob.system.service;

import com.coob.system.dao.MenuDao;
import com.coob.system.dao.RoleDao;
import com.coob.system.dao.RoleMenuDao;
import com.coob.system.dao.UserRoleDao;
import com.coob.system.domain.Menu;
import com.coob.system.domain.Role;
import com.coob.system.domain.RoleMenu;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class RoleService {
    @Resource
    private RoleDao roleDao;
    @Resource
    private MenuDao menuDao;
    @Resource
    private RoleMenuDao roleMenuDao;
    @Resource
    private UserRoleDao userRoleDao;


    /**
     * 保存新增角色 跟 菜单关联信息
     * @param role
     * @param menuIds
     * @return
     */
    public int insertRole(Role role, Integer[] menuIds) {
        //补充默认字段
        role.setState(1);

        //保存角色
        int flag = this.roleDao.insert(role);

        //保存菜单关联信息
        if( menuIds != null ){
            for(Integer mId : menuIds ){
                RoleMenu rm = new RoleMenu();
                rm.setRoleId(role.getId());
                rm.setMenuId(mId);
                this.roleMenuDao.insert(rm);
            }
        }

        return flag;
    }

    /**
     * 修改角色信息 跟 菜单关联表
     * @param role
     * @param menuIds
     * @return
     */
    public int updateRole(Role role, Integer[] menuIds) {
        int flag = this.roleDao.update(role);

        this.roleMenuDao.deleteByRoleId(role.getId());
        if( menuIds != null ){
            for(Integer mId : menuIds ){
                RoleMenu rm = new RoleMenu();
                rm.setRoleId(role.getId());
                rm.setMenuId(mId);

                this.roleMenuDao.insert(rm);
            }
        }

        return flag;
    }

    /**
     * 角色删除
     * @param roleId
     * @return
     */
    public int deleteRoleById(Integer roleId){
        int flag = this.roleDao.deleteById(roleId);
        this.userRoleDao.deleteByRoleid(roleId);
        this.roleMenuDao.deleteByRoleId(roleId);

        return flag;
    }

    /**
     * 根据Id查询角色信息（不含菜单信息）
     * @param roleId
     * @return
     */
    public Role selectRoleById(Integer roleId){
        return this.roleDao.selectById(roleId);
    }

    /**
     * 根据角色类别查询列表
     * @param roleType
     * @return
     */
    public List<Role> selectRoleListByType(Integer roleType){
        return this.roleDao.selectListByType(roleType);
    }

    /**
     * 根据用户查询赋权角色信息
     * @param userId
     * @return
     */
    public List<Role> selectRoleListByUserId(Integer userId){
        return this.roleDao.selectByUserId(userId);
    }


    /**
     * 条件查询角色列表
     * @param params
     * @return
     */
    public List<Role> selectByParams(Map<String, Object> params){
        return this.roleDao.selectByParams(params);
    }


    public List<Menu> selectMenuListAll(){
        return this.menuDao.selectList();
    }

    public List<Menu> selectMenuListByType(Integer menuType){
        return this.menuDao.selectListByType(menuType);
    }

    public List<Menu> selectMenuListByUserId(Integer userId) {
        return this.menuDao.selectByUserId(userId);
    }

    public List<Menu> selectMenuListByRoleId(Integer roleId) {
        return this.menuDao.selectByRoleId(roleId);
    }

}
