package com.coob.system.service;

import com.coob.system.dao.UserDao;
import com.coob.system.dao.UserRoleDao;
import com.coob.system.domain.User;
import com.coob.system.domain.UserRole;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

@Service
public class UserService {
    @Resource
    private UserDao userDao;
    @Resource
    private UserRoleDao userRoleDao;


    /**
     * 新增
     * @param user
     * @return
     */
    public int insert(User user){
        int flag = this.userDao.insert(user);

        if( user.getRoleId() != null && user.getRoleId() > 0 ) {
            UserRole ur = new UserRole();
            ur.setUserId(user.getId());
            ur.setRoleId(user.getRoleId());
            ur.setState(1);
            this.userRoleDao.insert(ur);
        }
        return flag;
    }

    /**
     * 修改
     * @param user
     * @return
     */
    public int update(User user){
        int flag = this.userDao.update(user);

        Integer userId = user.getId();
        Integer roleId = user.getRoleId();

        if( roleId != null && roleId > 0 ) {
            this.userRoleDao.deleteByUserId(userId);

            UserRole ur = new UserRole();
            ur.setUserId(userId);
            ur.setRoleId(roleId);
            ur.setState(1);
            this.userRoleDao.insert(ur);
        }

        return flag;
    }


    /**
     * 逻辑删除
     * @param id
     * @return
     */
    public int deleteById(Integer id){
        return this.userDao.deleteById(id);
    }

    /**
     * 根据id查询信息
     * @param id
     * @return
     */
    public User selectById(Integer id){
        return this.userDao.selectById(id);
    }

    /**
     * 根据登录账号查询用户信息
     * @param dlzh
     * @return
     */
    public User selectByDlzh(String dlzh){
        return this.userDao.selectByDlzh(dlzh);
    }

    /**
     * 查询所有有效的用户信息
     * @return
     */
    public List<User> selectListAll(){
        return this.userDao.selectListAll();
    }

    /**
     * 条件查询列表
     * @param params
     * @return
     */
    public List<User> selectByParams(Map<String,Object> params){
        return this.userDao.selectByParams(params);
    }

    /**
     * 根据userid查询关联表数据
     * @param userId
     * @return
     */
    public List<UserRole> selectListUserRoleByUserId(Integer userId){
        return this.userRoleDao.selectByUserId(userId);
    }

}
